@@ -1,6 +1,4 @@
-#[allow(unused_imports)]
-use crate::_prelude::*;
-use crate::{config, types::*};
+use crate::{_prelude::*, config, types::*};
 
 #[derive(Clone)]
 pub struct ParserProcessor {
