@@ -81,7 +81,7 @@ impl<JS: JobStateValues, TS: TaskStateValues, P: ParsedDocument> TaskScheduler<J
 
 		if task_response.task.link.is_waker {
 			for filter in &mut self.task_filters {
-				filter.wake(&mut self.job.ctx);
+				filter.wake(&mut self.job.ctx, &task_response);
 			}
 		}
 
@@ -113,6 +113,11 @@ impl<JS: JobStateValues, TS: TaskStateValues, P: ParsedDocument> TaskScheduler<J
 			self.schedule(Arc::new(task));
 		}
 
+		// TODO: figure a nice way to propagate errors in root tasks to Job Finished status
+		/*if self.pages_pending < 1 && task_response.task.is_root() {
+
+		}*/
+
 		let _ = self.update_tx.send_async(task_response).await;
 	}
 
